==> easyapi-0.8.2-sources.jar: cn/easyutil/easyapi/filter/config/ReadResponseConfig.java <==
package cn.easyutil.easyapi.filter.config;

import cn.easyutil.easyapi.filter.readRes.*;

import java.util.ArrayList;
import java.util.List;

public class ReadResponseConfig {

    private List<ReadResponseDescription> readDescriptions = new ArrayList<>();
    private List<ReadResponseIgnore> readIgnore = new ArrayList<>();
    private List<ReadResponseMockTemplate> readMockTemplate = new ArrayList<>();
    private List<ReadResponseRequired> readRequired = new ArrayList<>();
    private List<ReadResponseRetrunTypes> readRetrunTypes = new ArrayList<>();
    private List<ReadResponseShow> readShow = new ArrayList<>();


    public void addReadDescriptionsFilter(ReadResponseDescription readDescriptions) {
        this.readDescriptions.add(readDescriptions);
    }

    public void addReadIgnoreFilter(ReadResponseIgnore readIgnore) {
        this.readIgnore.add(readIgnore);
    }

    public void addReadMockTemplateFilter(ReadResponseMockTemplate readMockTemplate) {
        this.readMockTemplate.add(readMockTemplate);
    }

    public void addReadRequiredFilter(ReadResponseRequired readRequired) {
        this.readRequired.add(readRequired);
    }

    public void addReadRetrunTypesFilter(ReadResponseRetrunTypes readRetrunTypes) {
        this.readRetrunTypes.add(readRetrunTypes);
    }

    public void addReadShowFilter(ReadResponseShow readShow) {
        this.readShow.add(readShow);
    }

    public List<ReadResponseDescription> getReadDescriptions() {
        return readDescriptions;
    }

    public List<ReadResponseIgnore> getReadIgnore() {
        return readIgnore;
    }

    public List<ReadResponseMockTemplate> getReadMockTemplate() {
        return readMockTemplate;
    }

    public List<ReadResponseRequired> getReadRequired() {
        return readRequired;
    }

    public List<ReadResponseRetrunTypes> getReadRetrunTypes() {
        return readRetrunTypes;
    }

    public List<ReadResponseShow> getReadShow() {
        return readShow;
    }
}

==> easyapi-0.8.3-sources.jar: cn/easyutil/easyapi/filter/config/ReadResponseConfig.java <==
package cn.easyutil.easyapi.filter.config;

import cn.easyutil.easyapi.filter.readRes.*;

import java.util.ArrayList;
import java.util.List;

public class ReadResponseConfig {

    private List<ReadResponseDescription> readDescriptions = new ArrayList<>();
    private List<ReadResponseIgnore> readIgnore = new ArrayList<>();
    private List<ReadResponseMockTemplate> readMockTemplate = new ArrayList<>();
    private List<ReadResponseRequired> readRequired = new ArrayList<>();
    private List<ReadResponseReturnTypes> readReturnTypes = new ArrayList<>();
    private List<ReadResponseShow> readShow = new ArrayList<>();


    public void addReadDescriptionsFilter(ReadResponseDescription readDescriptions) {
        this.readDescriptions.add(readDescriptions);
    }

    public void addReadIgnoreFilter(ReadResponseIgnore readIgnore) {
        this.readIgnore.add(readIgnore);
    }

    public void addReadMockTemplateFilter(ReadResponseMockTemplate readMockTemplate) {
        this.readMockTemplate.add(readMockTemplate);
    }

    public void addReadRequiredFilter(ReadResponseRequired readRequired) {
        this.readRequired.add(readRequired);
    }

    public void addReadRetrunTypesFilter(ReadResponseReturnTypes readRetrunTypes) {
        this.readReturnTypes.add(readRetrunTypes);
    }

    public void addReadShowFilter(ReadResponseShow readShow) {
        this.readShow.add(readShow);
    }

    public List<ReadResponseDescription> getReadDescriptions() {
        return readDescriptions;
    }

    public List<ReadResponseIgnore> getReadIgnore() {
        return readIgnore;
    }

    public List<ReadResponseMockTemplate> getReadMockTemplate() {
        return readMockTemplate;
    }

    public List<ReadResponseRequired> getReadRequired() {
        return readRequired;
    }

    public List<ReadResponseReturnTypes> getReadReturnTypes() {
        return readReturnTypes;
    }

    public List<ReadResponseShow> getReadShow() {
        return readShow;
    }
}
